==> 1.0.2.tar.gz: example/lib/drop_down_parser2.dart <==
import 'package:flutter/cupertino.dart';
import 'package:json_to_form_with_theme/json_to_form_with_theme.dart';
import 'package:json_to_form_with_theme/parsers/widget_parser.dart';
import 'package:json_to_form_with_theme/widgets/drop_down_widget.dart';

import 'drop_down_widget2.dart';


class DropDownParser2 implements WidgetParser {
  DropDownParser2(this.name, this.description, this.id, this.chosenValue,
      this.values, this.onValueChanged, this.isBeforeHeader, this.index) {
    onValueChangedLocal = (String id, dynamic value) {
      chosenValue = value;
      if(onValueChanged != null) {
        onValueChanged!(id, value);
      }
    };
  }

  final OnValueChanged? onValueChanged;
  final bool isBeforeHeader;
  final String? description;
  final String name;
  final String id;
  final List<String> values;
  OnValueChanged? onValueChangedLocal;

  DropDownParser2.fromJson(Map<String, dynamic> json, this.onValueChanged,
      this.isBeforeHeader, this.index)
      : name = json['name'],
        description = json['description'],
        id = json['id'],
        values = json['values'].cast<String>(),
        chosenValue = json['chosen_value'];

  Map<String, dynamic> toJson() => {
        'name': name,
        'description': description,
        'id': id,
        'values': values,
        'chosen_value': chosenValue,
      };

  Widget getWidget() {
    return DropDownWidget2(
        key: ValueKey(chosenValue),
        name: name,
        id: id,
        values: values,
        description: description,
        chosenValue: chosenValue,
        isBeforeHeader: isBeforeHeader,
        onValueChanged: onValueChanged);
  }

  @override
  dynamic chosenValue;

  @override
  set id(String _id) {
    // TODO: implement id
  }

  @override
  int index;
}

==> 1.1.0.tar.gz: example/lib/drop_down_parser2.dart <==
import 'package:flutter/cupertino.dart';
import 'package:json_to_form_with_theme/json_to_form_with_theme.dart';
import 'package:json_to_form_with_theme/parsers/widget_parser.dart';
import 'package:json_to_form_with_theme/widgets/drop_down_widget.dart';

import 'drop_down_widget2.dart';

class DropDownParser2 implements WidgetParser {
  DropDownParser2(
      this.name,
      this.description,
      this.id,
      this.chosenValue,
      this.values,
      this.onValueChanged,
      this.isBeforeHeader,
      this.index,
      this.dateBuilder) {
    onValueChangedLocal = (String id, dynamic value) {
      chosenValue = value;
      if (onValueChanged != null) {
        onValueChanged!(id, value);
      }
    };
  }

  final OnValueChanged? onValueChanged;
  final bool isBeforeHeader;
  final String? description;
  final String name;
  final String id;
  final List<String> values;
  OnValueChanged? onValueChangedLocal;
  final Widget Function(int date)? dateBuilder;

  DropDownParser2.fromJson(Map<String, dynamic> json, this.onValueChanged,
      this.isBeforeHeader, this.index,
      [this.dateBuilder])
      : name = json['name'],
        description = json['description'],
        id = json['id'],
        time = json['time'],
        values = json['values'].cast<String>(),
        chosenValue = json['chosen_value'];

  Map<String, dynamic> toJson() => {
        'name': name,
        'description': description,
        'id': id,
        'time': time,
        'values': values,
        'chosen_value': chosenValue,
      };

  Widget getWidget() {
    return DropDownWidget2(
        key: ValueKey(chosenValue),
        name: name,
        id: id,
        values: values,
        description: description,
        chosenValue: chosenValue,
        dateBuilder: dateBuilder,
        time: time,
        isBeforeHeader: isBeforeHeader,
        onValueChanged: onValueChanged);
  }

  @override
  dynamic chosenValue;

  @override
  set id(String _id) {
    // TODO: implement id
  }

  @override
  int index;

  @override
  int? time;
}
